[![PyPI Downloads](https://static.pepy.tech/badge/rheedium)](https://pepy.tech/projects/rheedium)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

# Differentiable RHEED simulations in JAX

The aim of this project is to write RHEED simulations in [JAX](https://github.com/google/jax) so that it's end to end differentiable.

This will install the package as `rheedium`, which is the package that all the codes are.

The codes themselves are in the _src_ directory, following the modern toml convention as the _rheedium_ folder.